From: Chris Wright <chrisw@osdl.org>
To: akpm@osdl.org, torvalds@osdl.org
Cc: linux-kernel@vger.kernel.org
Subject: [PATCH 1/3][LSM] rename security_scaffolding_startup to security_init
Date: Thu, 21 Oct 2004 18:03:45 -0700 [thread overview]
Message-ID: <20041021180345.H2357@build.pdx.osdl.net> (raw)
Rename security_scaffolding_startup() to security_init(). It always
bothered me.
Signed-off-by: Chris Wright <chrisw@osdl.org>
include/linux/security.h | 2 +-
init/main.c | 2 +-
security/security.c | 8 ++++----
3 files changed, 6 insertions(+), 6 deletions(-)
===== include/linux/security.h 1.42 vs edited =====
--- 1.42/include/linux/security.h 2004-10-20 01:37:07 -07:00
+++ edited/include/linux/security.h 2004-10-21 16:36:30 -07:00
@@ -1903,7 +1903,7 @@
}
/* prototypes */
-extern int security_scaffolding_startup (void);
+extern int security_init (void);
extern int register_security (struct security_operations *ops);
extern int unregister_security (struct security_operations *ops);
extern int mod_reg_security (const char *name, struct security_operations *ops);
===== init/main.c 1.159 vs edited =====
--- 1.159/init/main.c 2004-10-08 21:09:14 -07:00
+++ edited/init/main.c 2004-10-21 16:35:35 -07:00
@@ -555,7 +555,7 @@
proc_caches_init();
buffer_init();
unnamed_dev_init();
- security_scaffolding_startup();
+ security_init();
vfs_caches_init(num_physpages);
radix_tree_init();
signals_init();
===== security/security.c 1.10 vs edited =====
--- 1.10/security/security.c 2004-08-24 02:08:51 -07:00
+++ edited/security/security.c 2004-10-21 16:44:06 -07:00
@@ -18,7 +18,7 @@
#include <linux/sched.h>
#include <linux/security.h>
-#define SECURITY_SCAFFOLD_VERSION "1.0.0"
+#define SECURITY_FRAMEWORK_VERSION "1.0.0"
/* things that live in dummy.c */
extern struct security_operations dummy_security_ops;
@@ -49,13 +49,13 @@
}
/**
* security_scaffolding_startup - initializes the security scaffolding framework
*
* This should be called early in the kernel initialization sequence.
*/
-int __init security_scaffolding_startup (void)
+int __init security_init(void)
{
- printk (KERN_INFO "Security Scaffold v" SECURITY_SCAFFOLD_VERSION
+ printk (KERN_INFO "Security Framework v" SECURITY_FRAMEWORK_VERSION
" initialized\n");
if (verify (&dummy_security_ops)) {
next reply other threads:[~2004-10-22 1:08 UTC|newest]
Thread overview: 3+ messages / expand[flat|nested] mbox.gz Atom feed top
2004-10-22 1:03 Chris Wright [this message]
2004-10-22 1:04 ` [PATCH 2/3][LSM] reduce noise during security_register Chris Wright
2004-10-22 1:07 ` [PATCH 3/3][LSM] Lindent security/security.c Chris Wright
Reply instructions:
You may reply publicly to this message via plain-text email
using any one of the following methods:
* Save the following mbox file, import it into your mail client,
and reply-to-all from there: mbox
Avoid top-posting and favor interleaved quoting:
https://en.wikipedia.org/wiki/Posting_style#Interleaved_style
* Reply using the --to, --cc, and --in-reply-to
switches of git-send-email(1):
git send-email \
--in-reply-to=20041021180345.H2357@build.pdx.osdl.net \
--to=chrisw@osdl.org \
--cc=akpm@osdl.org \
--cc=linux-kernel@vger.kernel.org \
--cc=torvalds@osdl.org \
/path/to/YOUR_REPLY
https://kernel.org/pub/software/scm/git/docs/git-send-email.html
* If your mail client supports setting the In-Reply-To header
@@ -49,13 +49,13 @@
}
/**
- * security_scaffolding_startup - initializes the security scaffolding framework
+ * security_init - initializes the security framework
*
* This should be called early in the kernel initialization sequence.
via mailto: links, try the mailto: link
Be sure your reply has a Subject: header at the top and a blank line
before the message body.
This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox
all inboxes | Powered by JetHome®